/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: AuditConsoleDelegate.as 19356 2010-03-04 21:02:36Z mancelin $
 * --------------------------------------------------------------------------
 */
package org.ow2.jonas.admin.auditconsole.business {
import com.adobe.cairngorm.business.ServiceLocator;

import org.ow2.jasmine.kerneos.common.business.AbsDelegateResponder;

/**
 * Delegate class to call java side.
 */
public class AuditConsoleDelegate extends AbsDelegateResponder implements IAuditConsoleDelegate {
    /**
     * Call the java side method for getting audit reports.
     */
    public function getReportObjects() : void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.getReportObjects();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }

	/**
	 * Call the java side method for getting Tree Nodes ID.
	 */
	public function getTreeNodesID(keyword:String, maxResults:Number, depth:Number) : void {
		// find service
		var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
		// call service
		var call : Object = service.getTreeAvailableNodes(keyword, maxResults, depth);
		// add the responder as a listener for the answer of the java side
		call.addResponder( this.responder );
	}

	/**
	 * Get the graph for the given node ID.
	 */
	public function getGraphNodeID(id: String) : void {
		// find service
		var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
		// call service
		var call : Object = service.getGraphNodeID(id);
		// add the responder as a listener for the answer of the java side
		call.addResponder( this.responder );
	}

    /**
     * Call the java side method for starting auditing service
     */
    public function startAuditing() : void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.startAuditing();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }
    /**
     * Call the java side method for stopping auditing service.
     */
    public function stopAuditing() : void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.stopAuditing();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }
    /**
     * Call the java side method for starting listening to audit notifications.
     */
    public function startListening() : void{
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.startListening();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }
    /**
     * Call the java side method for stopping listening to audit notifications.
     */
    public function unregister() : void{
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.unregister();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }


    public function getGlobalTop():void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.getGlobalTop();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }

    public function getEjbTop():void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.getEjbTop();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }

    public function getWebTop():void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.getWebTop();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }

    public function getJndiTop():void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.getJndiTop();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }


    public function setLimit(limit:int):void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.setLimit(limit);
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }


    public function getServerHealth():void {
        // find service
        var service : Object = ServiceLocator.getInstance().getRemoteObject( "auditService" );
        // call service
        var call : Object = service.getServerHealth();
        // add the responder as a listener for the answer of the java side
        call.addResponder( this.responder );
    }
}
}
