/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: Controller.as 19356 2010-03-04 21:02:36Z mancelin $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.auditconsole.control {
import com.adobe.cairngorm.control.FrontController;

import org.ow2.jonas.admin.auditconsole.command.*;
import org.ow2.jonas.admin.auditconsole.event.*;
import org.ow2.jonas.admin.auditconsole.model.*;

/**
 * Bind a type of command to an action.
 */
public class Controller extends FrontController {
    /**
     * Create an instance of the controller. Commands are initialized here.
     */
    public function Controller(){
        initialiseCommands();
    }
    /**
     * Add all the commands to the pool of commands.
     *
     * An unique ID was added to all the events in order
     * to prevent a Cairngorm issue: when a command event is dispatched,
     * every controller that registered this event type receives it, even if
     * located in another module. To prevent this from happening and triggering
     * multiple severe unexpected concurrence bugs, each event dispatched is
     * postfixed with this unique ID.
     */
    public function initialiseCommands() : void
    {
        // Retrieve the component model
        var model : AuditConsoleModelLocator = AuditConsoleModelLocator.getInstance();
        this.addCommand(AuditConsoleEvent.GET_REPORTS_OBJECTS, GetReportsObjectsCommand);
        this.addCommand(AuditConsoleEvent.START_AUDITING, StartAuditingCommand);
        this.addCommand(AuditConsoleEvent.STOP_AUDITING, StopAuditingCommand);
        this.addCommand(AuditConsoleEvent.START_LISTENING, StartListeningCommand);
        this.addCommand(AuditConsoleEvent.STOP_LISTENING, StopListeningCommand);
		this.addCommand(AuditConsoleEvent.TREE_GET_NODES_ID, TreeGetNodesCommand);
        
		this.addCommand(NodeConsoleEvent.TREE_GET_GRAPH, TreeGetGraphCommand);

        this.addCommand(AuditConsoleEvent.GET_GLOBAL_TOPS, GetGlobalTopsCommand);
        this.addCommand(AuditConsoleEvent.GET_EJB_TOPS, GetEJBTopsCommand);
        this.addCommand(AuditConsoleEvent.GET_WEB_TOPS, GetWEBTopsCommand);
        this.addCommand(AuditConsoleEvent.GET_JNDI_TOPS, GetJNDITopsCommand);
        this.addCommand(AuditConsoleEvent.SET_TOPS_LIMIT, SetTopLimitCommand);
        this.addCommand(AuditConsoleEvent.GET_SERVERHEALTH, GetServerHealthCommand);
    }
}
}
