/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.S.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: FilterUtils.as 19356 2010-03-04 21:02:36Z mancelin $
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.admin.auditconsole.util {
import org.ow2.jonas.admin.auditconsole.model.*;
import org.ow2.jonas.admin.auditconsole.vo.AuditConsoleTreeBranchEJBVO;
import org.ow2.jonas.admin.auditconsole.vo.AuditConsoleTreeBranchJNDIVO;
import org.ow2.jonas.admin.auditconsole.vo.AuditConsoleTreeBranchWEBVO;
import org.ow2.jonas.admin.auditconsole.vo.GenericAuditReportVO;

/**
 * Utility class for filtering.
 */
public class FilterUtils {
    /**
     * Constructor.
     */
    public function FilterUtils() { }
    /**
     * Get the good icon for the main tree.
     * @param item item of the tree.
     * @return  the good icon.
     */
    public static function mainTreeIcon(item:Object):Class {
        var node:XML = XML(item);
        if (node.@icon.search("jonasIcon") > -1) {
            return IconsUtils.getInstance().jonasIcon;
        } else if (node.@icon.search("methodIcon") > -1) {
            return AuditConsoleTreeBranchEJBVO.methodIcon;
        } else if (node.@icon.search("beanIcon") > -1) {
            return AuditConsoleTreeBranchEJBVO.beanIcon;
        } else if (node.@icon.search("webIcon") > -1) {
            return AuditConsoleTreeBranchWEBVO.tomcatIcon;
        } else if (node.@icon.search("tomcatPackIcon") > -1) {
            return AuditConsoleTreeBranchWEBVO.tomcatPackIcon;
        } else if (node.@icon.search("beanPackIcon") > -1) {
            return AuditConsoleTreeBranchEJBVO.beanPackIcon;
        } else if (node.@icon.search("jndiIcon") > -1)  {
            return AuditConsoleTreeBranchJNDIVO.jndiIcon;
        } else {
            return null
        }
    }
    /**
     * Get the good icon for the main grid.
     * @param item item of the grid.
     * @return  the good icon.
     */
    private static function listIcon(item:Object):Class {
        var report:GenericAuditReportVO = (item as GenericAuditReportVO);
        if ((item as GenericAuditReportVO).callLevel > 0) {
            if (AuditConsoleModelLocator.getInstance().topDown) {
                return IconsUtils.getInstance().reverseArrowIcon;
            } else {
                return IconsUtils.getInstance().arrowIcon;
            }
        } else {
            if (report.isEJBInvocation()) {
                return AuditConsoleTreeBranchEJBVO.methodIcon;
            } else if (report.isWEBInvocation()) {
                return AuditConsoleTreeBranchWEBVO.tomcatIcon;
            } else if (report.isJNDIInvocation()) {
                return AuditConsoleTreeBranchJNDIVO.jndiIcon;
            } else {
                return IconsUtils.getInstance().jonasIcon;
            }
        }
    }
}
}